@@ -20,7 +20,7 @@ project = 'rcis'
 year = '2022'
 author = 'Enrico Facca'
 copyright = '{0}, {1}'.format(year, author)
-version = release = '0.1.0'
+version = release = '0.2.1'
 
 pygments_style = 'trac'
 templates_path = ['.']
@@ -42,6 +42,15 @@ html_sidebars = {
 }
 html_short_title = '%s-%s' % (project, version)
 
-napoleon_use_ivar = True
+napoleon_use_ivar = False
 napoleon_use_rtype = False
 napoleon_use_param = False
+napoleon_include_init_with_doc = True
+napoleon_custom_sections = [('Returns', 'params_style')]
+
+
+autodoc_typehints='description'
+autodoc_typehints_format='short'
+
+
+autodoc_member_order = 'bysource'
